{
 "cells": [
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "# Lyapunov exponents of the Teichmüller flow\n",
    "## Vincent Delecroix, Bordeaux (France)\n",
    "\n",
    "This notebook is a companion to the [pdf presentation](https://wiki.sagemath.org/days79?action=AttachFile&do=get&target=VincentDelecroix-beamer_jerusalem_2016.pdf) made at Jerusalem in November 2016 at the occasion of [Sage days 79](https://wiki.sagemath.org/days79)."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 8,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "from IPython.display import HTML"
   ]
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## demo 1: rational billiard"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 77,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "# this huge piece of code is used to generate billiard and translation surface trajectories\n",
    "\n",
    "def solve(x,u,y,v):\n",
    "    r\"\"\"\n",
    "    Return (a,b) so that: x + au = y + bv\n",
    "    \"\"\"\n",
    "    d = -u[0] * v[1] + u[1] * v[0]\n",
    "    a = v[1] * (x[0]-y[0]) + v[0] * (y[1] - x[1])\n",
    "    b = u[1] * (x[0]-y[0]) + u[0] * (y[1] - x[1])\n",
    "    return (a/d,b/d)\n",
    "\n",
    "def frm(vectors, x, i, d):\n",
    "    r\"\"\"\n",
    "    First return map in the triangle determined by ``vectors``.\n",
    "\n",
    "    INPUT:\n",
    "\n",
    "    - ``x`` - a real number in (0,1)\n",
    "\n",
    "    - ``i`` - either 0, 1 or 2 (determine the side)\n",
    "\n",
    "    - ``d`` - an angle\n",
    "    \"\"\"\n",
    "    d = Va(d)\n",
    "    assert normals[i].dot_product(d) > 0, \"dot product with {} is {}\".format(normals[i], normals[i].dot_product(d))\n",
    "    j = (i+1)%3\n",
    "    k = (j+1)%3\n",
    "\n",
    "    # we assume that the base of i is at (0,0)\n",
    "    # solve(x,u,y,v)\n",
    "    tj,bj = solve(x*vectors[i], d, vectors[i], vectors[j])\n",
    "    tk,bk = solve(x*vectors[i], d, -vectors[k], vectors[k])\n",
    "\n",
    "    assert (0 < bj < 1) + (0 < bk < 1) == 1\n",
    "\n",
    "    if 0 < bj < 1:\n",
    "        return bj,j\n",
    "    else:\n",
    "        return bk,k\n",
    "\n",
    "class Triangle(object):\n",
    "    r\"\"\"\n",
    "    A class to handle intersection of lines with triangles\n",
    "    \"\"\"\n",
    "    def __init__(self, v0, v1, v2, t=0, color=None):\n",
    "        r\"\"\"\n",
    "        INPUT:\n",
    "        \n",
    "        - ``v0``, ``v1``, ``v2`` -- vertices\n",
    "        \n",
    "        - ``t`` -- optional translate\n",
    "        \n",
    "        - ``color`` -- optional color\n",
    "        \"\"\"\n",
    "        s = Sequence([v0,v1,v2])\n",
    "        self._vector_space = V = s.universe()\n",
    "        self._vectors = list(s)\n",
    "        self._normals = [V((-v[1],v[0]))/v.norm() for v in self._vectors]\n",
    "        self._translate = V(t)\n",
    "        self._color = color\n",
    "        \n",
    "    def area(self):\n",
    "        x0,y0 = self._vector_space.zero()\n",
    "        x1,y1 = self._vectors[0]\n",
    "        x2,y2 = -self._vectors[2]\n",
    "        return ((x0+x1)*(y1-y0) + (x1+x2)*(y2-y1) + (x2+x0)*(y0-y2)) / 2\n",
    "        \n",
    "        \n",
    "\n",
    "    def plot(self, color=None):\n",
    "        if color is None and self._color:\n",
    "            color = self._color\n",
    "        V = self._vector_space\n",
    "        return polygon2d([self._translate + V.zero(),\n",
    "                          self._translate + self._vectors[0],\n",
    "                          self._translate - self._vectors[2]], alpha=0.3, color=color)\n",
    "\n",
    "    def frm(self, i, x, d):\n",
    "        V = self._vector_space\n",
    "        d = V(d)\n",
    "        assert self._normals[i].dot_product(d) > 0, \"dot product with {} is {}\".format(self._normals[i], self._normals[i].dot_product(d))\n",
    "        j = (i+1)%3\n",
    "        k = (j+1)%3\n",
    "    \n",
    "        # we assume that the base of i is at (0,0)\n",
    "        # solve(x,u,y,v)\n",
    "        tj,bj = solve(x*self._vectors[i], d, self._vectors[i], self._vectors[j])\n",
    "        tk,bk = solve(x*self._vectors[i], d, -self._vectors[k], self._vectors[k])\n",
    "    \n",
    "        assert (0 < bj < 1) + (0 < bk < 1) == 1\n",
    "    \n",
    "        if 0 < bj < 1:\n",
    "            return j,bj\n",
    "        else:\n",
    "            return k,bk\n",
    "            \n",
    "    def code_to_pos(self, i, x):\n",
    "        if i == 0:\n",
    "            return self._translate + x * self._vectors[0]\n",
    "        elif i == 1:\n",
    "            return self._translate + self._vectors[0] + x*self._vectors[1]\n",
    "        elif i == 2:\n",
    "            return self._translate + (x-1)*self._vectors[2]\n",
    "        else:\n",
    "            raise ValueError(\"got i={} and x={}\".format(i,x))\n",
    "\n",
    "class TriangulatedSurface:\n",
    "    def __init__(self, triangles, gluings):\n",
    "        self._triangles = triangles\n",
    "        self._gluings = gluings\n",
    "        \n",
    "    def orbit(self, t, s, x, d, iterations=10):\n",
    "        r\"\"\"\n",
    "        INPUT:\n",
    "\n",
    "        - ``t`` -- triangle\n",
    "            \n",
    "        - ``s`` -- side 0, 1 or 2\n",
    "        \n",
    "        - ``d`` -- direction\n",
    "        \"\"\"\n",
    "        orbit = []\n",
    "        for _ in range(iterations):\n",
    "            s1,x1 = self._triangles[t].frm(s,x,d)\n",
    "            orbit.append(((t,s,x,s1,x1)))\n",
    "            x = 1-x1\n",
    "            t,s = self._gluings[t][s1]\n",
    "        return orbit\n",
    "\n",
    "    def plot(self, labels=False):\n",
    "        G = Graphics()\n",
    "        for i,t in enumerate(self._triangles):\n",
    "            G += t.plot()\n",
    "            if labels:\n",
    "                barycenter = t._translate + (2*t._vectors[0] + t._vectors[1]) / 3\n",
    "                G += text(str(i), barycenter)\n",
    "        return G\n",
    "        \n",
    "    def plot_orbit(self, t, s, x, d, iterations=10):\n",
    "        G = self.plot()\n",
    "        for t,s0,x0,s1,x1 in self.orbit(t,s,x,d,iterations):\n",
    "            p0 = self._triangles[t].code_to_pos(s0,x0)\n",
    "            p1 = self._triangles[t].code_to_pos(s1,x1)\n",
    "            G += line2d([p0,p1], color='black')\n",
    "        return G\n",
    "\n",
    "class TriangularBilliard(Triangle):      \n",
    "    def reflexion(self, d, i):\n",
    "        r\"\"\"\n",
    "        Reflexion of the direction ``d`` on the side ``i``\n",
    "        \"\"\"\n",
    "        c,s = self._normals[i]\n",
    "        c2 = c*c - s*s\n",
    "        s2 = 2*c*s\n",
    "        return self._vector_space((c2*d[0] + s2*d[1], s2*d[0] - c2*d[1]))\n",
    "\n",
    "    def orbit(self, i, x, d, iterations=10):\n",
    "        orbit = [(i,x)]\n",
    "        for _ in range(iterations):\n",
    "            i,x = self.frm(i,x,d)\n",
    "            orbit.append((i,x))\n",
    "            d = -self.reflexion(d,i)\n",
    "        return orbit\n",
    "\n",
    "    def plot_orbit(self, i, x, d, iterations=10):\n",
    "        G = self.plot()\n",
    "        orbit = self.orbit(i,x,d,iterations)\n",
    "        pts = [self.code_to_pos(j,x) for j,x in orbit]\n",
    "        return G + line2d(pts, color='black')\n",
    "\n",
    "def rot(angle, x):\n",
    "    angle = angle.n()\n",
    "    c = angle.cos()\n",
    "    s = angle.sin()\n",
    "    return x.parent()((c*x[0] - s*x[1], s*x[0] + c*x[1]))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 78,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "colors = [(1.0, 0.0, 0.0),\n",
    " (0.5, 1.0, 0.0),\n",
    " (0.0, 1.0, 0.25),\n",
    " (1.0, 0.0, 0.75),\n",
    " (0.0, 0.25, 1.0),\n",
    " (0.0, 1.0, 1.0),\n",
    " (1.0, 0.75, 0.0),\n",
    " (0.5, 0.0, 1.0)]"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 79,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "x = polygen(ZZ)\n",
    "K.<sqrt2> = NumberField(x^2 - 2, embedding=AA(2).sqrt())\n",
    "Va = VectorSpace(RDF,2)\n",
    "vectors0 = [ Va((2,0)), Va((-1,1+sqrt2)), Va((-1,-1-sqrt2))]\n",
    "T0 = Triangle(*vectors0, color=colors[0])\n",
    "T1 = Triangle(*[rot(pi/4, v) for v in vectors0],   t=(2,0), color=colors[1])\n",
    "T2 = Triangle(*[rot(pi/2, v) for v in vectors0],   t=(2+sqrt2,sqrt2), color=colors[2])\n",
    "T3 = Triangle(*[rot(3*pi/4, v) for v in vectors0], t=(2+sqrt2,2+sqrt2), color=colors[3])\n",
    "T4 = Triangle(*[rot(pi, v) for v in vectors0],     t=(2,2+2*sqrt2), color=colors[4])\n",
    "T5 = Triangle(*[rot(5*pi/4, v) for v in vectors0], t=(0,2+2*sqrt2), color=colors[5])\n",
    "T6 = Triangle(*[rot(3*pi/2, v) for v in vectors0], t=(-sqrt2,2+sqrt2), color=colors[6])\n",
    "T7 = Triangle(*[rot(7*pi/4, v) for v in vectors0], t=(-sqrt2,sqrt2), color=colors[7])\n",
    "gluings = [[(4,0),(1,2),(7,1)],\n",
    "           [(5,0),(2,2),(0,1)],\n",
    "           [(6,0),(3,2),(1,1)],\n",
    "           [(7,0),(4,2),(2,1)],\n",
    "           [(0,0),(5,2),(3,1)],\n",
    "           [(1,0),(6,2),(4,1)],\n",
    "           [(2,0),(7,2),(5,1)],\n",
    "           [(3,0),(0,2),(6,1)]]\n",
    "\n",
    "O = TriangulatedSurface([T0,T1,T2,T3,T4,T5,T6,T7], gluings)\n",
    "T = TriangularBilliard(*vectors0, color=colors[0])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 80,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAd0AAAJICAYAAAAkfj4DAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
      "text/plain": [
       "Graphics object consisting of 3 graphics primitives"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "# first picture of the beamer\n",
    "x = 0.3\n",
    "d = Va((0.27324123005978,1.2314486735))\n",
    "p = T.code_to_pos(0,x)\n",
    "G = T.plot_orbit(0,x,d,iterations=6)\n",
    "#(circle(p, 0.05, fill=True, color='black') + G).save('/tmp/billiard1.pdf', aspect_ratio=1, axes=False, figsize=3)\n",
    "(circle(p, 0.05, fill=True, color='black') + G).show(aspect_ratio=1, axes=False)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 81,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAd0AAAJICAYAAAAkfj4DAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
      "text/plain": [
       "Graphics object consisting of 3 graphics primitives"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "# the unfolded picture\n",
    "x = 0.3\n",
    "d = Va((0.27324123005978,1.2314486735))\n",
    "p = T.code_to_pos(0,x)\n",
    "G = T.plot_orbit(0,x,d,iterations=15)\n",
    "#(circle(p, 0.05, fill=True, color='black') + G).save('/tmp/billiard2.pdf', aspect_ratio=1, axes=False, figsize=3)\n",
    "(circle(p, 0.05, fill=True, color='black') + G).show(aspect_ratio=1, axes=False)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 82,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "G2 = O.plot_orbit(0,0,x,d,iterations=15)\n",
    "(circle(p, 0.05, fill=True, color='black') + G2).save('/tmp/billiard3.pdf', aspect_ratio=1, axes=False, figsize=3)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 83,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "# compute a sequence of graphics to build a video\n",
    "x = 0.3\n",
    "d = Va((0.27324123005978,1.2314486735))\n",
    "limits = [-sqrt2-.1, 2+sqrt2+.1, -.1, 2+2*sqrt2]\n",
    "G = []\n",
    "for n in range(30):\n",
    "    G1 = O.plot_orbit(0,0,x,d,iterations=n)\n",
    "    G1.axes(False)\n",
    "    G1.set_axes_range(*limits)\n",
    "    G2 = T.plot_orbit(0,x,d,iterations=n)\n",
    "    G2.axes(False)\n",
    "    G2.set_axes_range(*limits)\n",
    "    G.append(graphics_array([G2,G1]))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 84,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "# assembles the graphics in a video\n",
    "A = animate(G)\n",
    "A.ffmpeg('demo1.mp4', delay=40)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 85,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/html": [
       "<video width=\"640\" height=\"480\" controls>\n",
       "  <source src=\"demo1.mp4\" type=\"video/mp4\">\n",
       "</video>"
      ],
      "text/plain": [
       "<IPython.core.display.HTML object>"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "%%HTML\n",
    "<video width=\"640\" height=\"480\" controls>\n",
    "  <source src=\"demo1.mp4\" type=\"video/mp4\">\n",
    "</video>"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "## Deviation of Birkhoff sums in the octagon\n",
    "\n",
    "We consider the horizontal side in the octagon (the edge common to triangle 0 and 4 below). And compute how many intersections we have up to a given time (Birkhoff sums)."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 86,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAkgAAAJICAYAAACaHhuvAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nSUVORK5CYII=\n",
      "text/plain": [
       "Graphics object consisting of 16 graphics primitives"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "O.plot(labels=True).show(axes=False)"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 87,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "19.313708499\n"
     ]
    }
   ],
   "source": [
    "# total area of the octagon\n",
    "area = 8 * O._triangles[0].area()\n",
    "print area"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 88,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "def birkhoff_sums_octagon(x, d, num_intersection=1000):\n",
    "    r\"\"\"\n",
    "    Compute the number of intersections of the trajectory\n",
    "    from ``x`` in the vertical direction ``d`` and the horizontal\n",
    "    segment in the octagon.\n",
    "    \n",
    "    OUTPUT:\n",
    "    \n",
    "    A list of pairs `(length, intersection)`.\n",
    "    \"\"\"\n",
    "    bs = [(0,0)]\n",
    "    d /= d.norm()  # normalize the direction\n",
    "    v = 0\n",
    "    length = 0.0\n",
    "    for i, sin, xin, sout, xout in O.orbit(0, 0, 0.11214, d, num_intersection):\n",
    "        t = O._triangles[i]\n",
    "        p0 = t.code_to_pos(sin, xin)\n",
    "        p1 = t.code_to_pos(sout, xout)\n",
    "        length += (p1 - p0).norm()\n",
    "        if i == 0 and sin == 0:\n",
    "            v += 1\n",
    "            bs.append((length,v))\n",
    "    return bs"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "Equidistribution (Kerckhoff-Masur-Smillie theorem): we print with the code below the number of intersections of a trajectory divided by the time versus the transversal measure of the side"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": 89,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAw8AAAJICAYAAAAn9ti2AAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nAAAAAJhCeAAAAABgCuEBAAAAgCn/H7lUL6if8HNnAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "Graphics Array of size 1 x 2"
      ]
     },
     "execution_count": 89,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "d = Va((0.12314311, 0.657123141))\n",
    "x = 0.5\n",
    "n = 35\n",
    "bs = birkhoff_sums_octagon(x,d,n)\n",
    "graphics_array([O.plot_orbit(0,0,x,d,iterations=n), point2d(bs)])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": 98,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAw0AAAJICAYAAAAjAwiLAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
      "text/plain": [
       "Graphics object consisting of 2 graphics primitives"
      ]
     },
     "execution_count": 98,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "d = Va((0.471231120312, 0.711212768921))\n",
    "d = d / d.norm()\n",
    "bs = birkhoff_sums_octagon(0, d, 100)\n",
    "l = bs[-1][0]\n",
    "mean = d.dot_product(vector((0,2))) / area\n",
    "point2d(bs) + line2d([(0,0), (l,mean*l)], color='red')"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": 114,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "direction                 empirical mean    transversal measure\n",
      "(0.8033, 0.5955)          0.056278          0.061669       \n",
      "(0.6575, 0.7534)          0.080703          0.078018       \n",
      "(0.8602, 0.5100)          0.051629          0.052810       \n",
      "(0.7882, 0.6155)          0.056878          0.063735       \n",
      "(0.07193, 0.9974)         0.11069           0.10329        \n",
      "(0.3802, 0.9249)          0.11372           0.095778       \n",
      "(0.8467, 0.5321)          0.052366          0.055096       \n",
      "(0.8180, 0.5752)          0.061633          0.059569       \n",
      "(0.7301, 0.6833)          0.068280          0.070759       \n",
      "(0.06648, 0.9978)         0.10504           0.10332        \n"
     ]
    }
   ],
   "source": [
    "print \"{:25} {:17} {:15}\".format(\"direction\", \"empirical mean\", \"transversal measure\")\n",
    "for _ in range(10):\n",
    "    d = (RDF**2).random_element(min=0,max=1) # random direction\n",
    "    d /= d.norm()                            # normalize it\n",
    "    x = RDF.random_element(0,1)              # initial point\n",
    "    bs = birkhoff_sums_octagon(x, d)         # the number of intersections\n",
    "    mean = d.dot_product(vector((0,2))) / area\n",
    "    empirical = bs[-1][1] / bs[-1][0]\n",
    "    print \"{:25} {:17} {:15}\".format(d.n(digits=4), empirical.n(digits=5), mean.n(digits=5))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "markdown",
   "metadata": {},
   "source": [
    "In the cell below we compute and plot the renormalized Birkhoff sums $$i(S,\\gamma,\\theta,x,t) - t \\mu_\\theta(\\gamma)$$ for $t$ in wider and wider ranges."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": 129,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "name": "stdout",
     "output_type": "stream",
     "text": [
      "direction: (0.01320635534248983, 0.9999127922866913)   mean=0.103544359939\n"
     ]
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAw0AAAJICAYAAAAjAwiLAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
      "text/plain": [
       "Graphics object consisting of 1 graphics primitive"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAw0AAAJICAYAAAAjAwiLAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n",
      "text/plain": [
       "Graphics object consisting of 1 graphics primitive"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAw0AAAJHCAYAAADSVbpeAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\nJXueWOpcAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "Graphics object consisting of 1 graphics primitive"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAw0AAAJICAYAAAAjAwiLAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n0BnNW5rnAAAAAElFTkSuQmCC\n",
      "text/plain": [
       "Graphics object consisting of 1 graphics primitive"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    },
    {
     "data": {
      "image/png": "iVBORw0KGgoAAAANSUhEUgAAAw0AAAJICAYAAAAjAwiLAAAABHNCSVQICAgIfAhkiAAAAAlwSFlz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\n70wAAAAASUVORK5CYII=\n",
      "text/plain": [
       "Graphics object consisting of 1 graphics primitive"
      ]
     },
     "metadata": {},
     "output_type": "display_data"
    }
   ],
   "source": [
    "d = (RDF**2).random_element(min=0,max=1)    # random direction\n",
    "d /= d.norm()                               # normalize it\n",
    "mean = d.dot_product(vector((0,2))) / area  # transversal length\n",
    "bs = birkhoff_sums_octagon(0.5, d, 10**6)   # Birkhoff sum\n",
    "rbs = [(x, y - x*mean) for x,y in bs]       # renormalized Birkhoff sums\n",
    "print \"direction: {}   mean={}\".format(d, mean)\n",
    "for n in [(RR(len(rbs))**(k/5.)).floor() for k in range(1,6)]:\n",
    "    point2d(rbs[:n]).show()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 58,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "# to save the picture of the renormalized Birkhoff sum, just uncomment the line below\n",
    "# point2d(rbs, pointsize=1).save('/tmp/birkhoff2.pdf', figsize=(4,2))"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "markdown",
   "metadata": {
    "collapsed": true
   },
   "source": [
    "# Computing Lyapunov exponents using the surface dynamics package\n",
    "\n",
    "This part needs the surface dynamics package to be installed. To that purpose, open a terminal and run the following command\n",
    "\n",
    "    sage -pip install surface_dynamics\n",
    "\n",
    "The code in this package was written mostly by me and the part about Lyapunov exponents by Charles Fougeron."
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 114,
   "metadata": {
    "collapsed": false
   },
   "outputs": [],
   "source": [
    "from surface_dynamics.all import *"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": 121,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "H_2(2)"
      ]
     },
     "execution_count": 121,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "# here is more or less the Lyapunov exponents associated to the octagon\n",
    "# (exact values are 1, 1/3)\n",
    "p = iet.Permutation('A B C D', 'B D A C')\n",
    "p.stratum()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 117,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "[1.0055853164501598, 0.3296131518846267]"
      ]
     },
     "execution_count": 117,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "p.lyapunov_exponents_H_plus()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  },
  {
   "cell_type": "code",
   "execution_count": 122,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": [
    "# and here the Lyapunov exponents associated to the windtree\n",
    "# (exact values are 1, 2/3, 2/3, 1/3, 1/3)\n",
    "S4 = SymmetricGroup(4)\n",
    "i = S4('')\n",
    "h = S4('(1,2)(3,4)')\n",
    "v = S4('(1,3)(2,4)')\n",
    "q = p.cover([i,h,v,i])"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": 123,
   "metadata": {
    "collapsed": false
   },
   "outputs": [
    {
     "data": {
      "text/plain": [
       "[1.0019240494550279,\n",
       " 0.676566352078252,\n",
       " 0.6656948165428316,\n",
       " 0.35055284930066477,\n",
       " 0.33435555212474305]"
      ]
     },
     "execution_count": 123,
     "metadata": {},
     "output_type": "execute_result"
    }
   ],
   "source": [
    "q.lyapunov_exponents_H_plus()"
   ]
  },
  {
   "cell_type": "code",
   "execution_count": null,
   "metadata": {
    "collapsed": true
   },
   "outputs": [],
   "source": []
  }
 ],
 "metadata": {
  "kernelspec": {
   "display_name": "SageMath",
   "language": "",
   "name": "sagemath"
  },
  "language_info": {
   "codemirror_mode": {
    "name": "ipython",
    "version": 2
   },
   "file_extension": ".py",
   "mimetype": "text/x-python",
   "name": "python",
   "nbconvert_exporter": "python",
   "pygments_lexer": "ipython2",
   "version": "2.7.10"
  }
 },
 "nbformat": 4,
 "nbformat_minor": 0
}
